## Introduction

A wrapper based on [lightning-template](https://github.com/shenmishajing/lightning_template) for mmlab repos to use in [project-template](https://github.com/shenmishajing/project_template)
